pub struct BootstrapProcConfig {
pub create_rank: usize,
pub client_config_override: Attrs,
pub proc_bind: Option<ProcBind>,
pub bootstrap_command: Option<BootstrapCommand>,
}Expand description
The configuration used for bootstrapped procs.
Fields
create_rank: usizeThe proc’s create rank.
client_config_override: AttrsConfig values to set on the spawned proc’s global config,
at the ClientOverride layer.
proc_bind: Option<ProcBind>Optional per-process CPU/NUMA binding configuration.
When set, the bootstrap command is wrapped with numactl
(on NUMA systems) or taskset (Linux fallback) before launch.
bootstrap_command: Option<BootstrapCommand>Optional bootstrap command override. When set, this command is used to spawn the proc instead of the manager’s default bootstrap command.